==> pysatNASA-0.0.2.tar.gz: pysatNASA-0.0.2/pysatNASA/instruments/methods/cnofs.py <==
# -*- coding: utf-8 -*-
"""Provides non-instrument specific routines for DE2 data"""

ackn_str = ' '.join(("The Communication Navigation Outage Forecast System",
                     "(C/NOFS) satellite data is provided through CDAWeb"))

refs = {'mission': ' '.join(('de La Beaujardière, O., et al. (2004), C/NOFS: A',
                             'mission to forecast scintillations, J. Atmos.',
                             'Sol. Terr. Phys., 66, 1573–1591,',
                             'doi:10.1016/j.jastp.2004.07.030.')),
        'ivm': ' '.join(('Burrell, Angeline G., Equatorial topside magnetic',
                         'field-aligned ion drifts at solar minimum, The',
                         'University of Texas at Dallas, ProQuest',
                         'Dissertations Publishing, 2012. 3507604.\n',
                         'Hairston, M. R., W. R. Coley, and R. A. Heelis',
                         '(2010), Mapping the duskside topside ionosphere with',
                         'CINDI and DMSP, J. Geophys. Res.,115, A08324,',
                         'doi:10.1029/2009JA015051')),
        'plp': ' '.join(('')),
        'vefi': ' '.join(('Pfaff, R., et al. (2010), Observations of DC',
                          'electric fields in the low‐latitude ionosphere and',
                          'their variations with local time, longitude, and',
                          'plasma density during extreme solar minimum, J.',
                          'Geophys. Res., 115, A12324,',
                          'doi:10.1029/2010JA016023.'))
        }

==> pysatNASA-0.0.3.tar.gz: pysatNASA-0.0.3/pysatNASA/instruments/methods/cnofs.py <==
# -*- coding: utf-8 -*-
"""Provides non-instrument specific routines for C/NOFS data."""

ackn_str = ' '.join(("The Communication Navigation Outage Forecast System",
                     "(C/NOFS) satellite data is provided through CDAWeb"))

refs = {'mission': ' '.join(('de La Beaujardière, O., et al. (2004), C/NOFS: A',
                             'mission to forecast scintillations, J. Atmos.',
                             'Sol. Terr. Phys., 66, 1573–1591,',
                             'doi:10.1016/j.jastp.2004.07.030.')),
        'ivm': ' '.join(('Burrell, Angeline G., Equatorial topside magnetic',
                         'field-aligned ion drifts at solar minimum, The',
                         'University of Texas at Dallas, ProQuest',
                         'Dissertations Publishing, 2012. 3507604.\n',
                         'Hairston, M. R., W. R. Coley, and R. A. Heelis',
                         '(2010), Mapping the duskside topside ionosphere with',
                         'CINDI and DMSP, J. Geophys. Res.,115, A08324,',
                         'doi:10.1029/2009JA015051')),
        'plp': ' '.join(('')),
        'vefi': ' '.join(('Pfaff, R., et al. (2010), Observations of DC',
                          'electric fields in the low‐latitude ionosphere and',
                          'their variations with local time, longitude, and',
                          'plasma density during extreme solar minimum, J.',
                          'Geophys. Res., 115, A12324,',
                          'doi:10.1029/2010JA016023.'))
        }
